@@ -43,7 +43,6 @@ sys.path.insert(
 
 # isort:start
 
-from nuitka.freezer.RuntimeTracing import getRuntimeTraceOfLoadedFiles
 from nuitka.tools.testing.Common import (
     checkLoadedFileAccesses,
     checkRequirements,
@@ -57,6 +56,7 @@ from nuitka.tools.testing.Common import (
     setup,
     test_logger,
 )
+from nuitka.tools.testing.RuntimeTracing import getRuntimeTraceOfLoadedFiles
 from nuitka.utils.FileOperations import removeDirectory
 from nuitka.utils.Timing import TimerReport
 from nuitka.utils.Utils import isMacOS, isWin32Windows
@@ -169,7 +169,6 @@ def main():
             continue
 
         if filename == "PandasUsing.py":
-            extra_flags.append("plugin_enable:numpy")
             extra_flags.append("plugin_enable:no-qt")
             extra_flags.append("plugin_disable:pylint-warnings")
 
@@ -180,10 +179,6 @@ def main():
             # For the warnings.
             extra_flags.append("ignore_warnings")
 
-        if filename == "GlfwUsing.py":
-            # For the warnings.
-            extra_flags.append("plugin_enable:numpy")
-
         if filename == "PasslibUsing.py":
             # For the warnings.
             extra_flags.append("ignore_warnings")
@@ -199,6 +194,9 @@ def main():
                 reportSkip("irrelevant Python version", ".", filename)
                 continue
 
+            if filename != "PySide6":
+                extra_flags.append("ignore_warnings")
+
         test_logger.info(
             "Consider output of standalone mode compiled program: %s" % filename
         )
